/********************************************************************************
** Form generated from reading UI file 'SettingsDialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGSDIALOG_H
#define UI_SETTINGSDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_SettingsDialog
{
public:
    QVBoxLayout *_13;
    QTabWidget *tabWidget;
    QWidget *tabRegular;
    QVBoxLayout *verticalLayout_3;
    QGroupBox *groupApp;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *cbAutoUpdate;
    QCheckBox *cbShowVersion;
    QCheckBox *cbAutoHide;
    QCheckBox *cbPreventSleep;
    QCheckBox *cbCloseToTray;
    QHBoxLayout *horizontalLayout_8;
    QLabel *lblTrayIconStyle;
    QRadioButton *rbIconColorful;
    QRadioButton *rbIconMono;
    QGroupBox *groupSecurity;
    QVBoxLayout *_11;
    QWidget *widgetTlsCert;
    QHBoxLayout *_12;
    QLabel *lblTlsCertInfo;
    QLabel *lblTlsCert;
    QLineEdit *lineTlsCertPath;
    QPushButton *btnTlsCertPath;
    QHBoxLayout *horizontalLayout_5;
    QLabel *lblTlsKeyLength;
    QComboBox *comboTlsKeyLength;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *btnTlsRegenCert;
    QCheckBox *cbRequireClientCert;
    QSpacerItem *verticalSpacer_2;
    QSpacerItem *verticalSpacer_3;
    QWidget *tabAdvanced;
    QVBoxLayout *verticalLayout_4;
    QGroupBox *groupNetworking;
    QHBoxLayout *horizontalLayout;
    QLabel *lblNetworkIp;
    QComboBox *comboInterface;
    QSpacerItem *horizontalSpacer;
    QLabel *lblPort;
    QSpinBox *sbPort;
    QSpacerItem *horizontalSpacer_3;
    QGroupBox *groupLogs;
    QGridLayout *_3;
    QLabel *lblLogLevel;
    QComboBox *comboLogLevel;
    QWidget *widgetLogFilename;
    QHBoxLayout *_4;
    QLabel *labelLogPath;
    QSpacerItem *horizontalSpacer_7;
    QLineEdit *lineLogFilename;
    QPushButton *btnBrowseLog;
    QCheckBox *cbLogToFile;
    QSpacerItem *horizontalSpacer_5;
    QLabel *lblDebugWarning;
    QCheckBox *cbGuiDebug;
    QGroupBox *groupService;
    QGridLayout *_6;
    QCheckBox *cbElevateDaemon;
    QWidget *widgetLanguage;
    QHBoxLayout *horizontalLayout_3;
    QLabel *lblLanguage;
    QComboBox *comboLanguage;
    QWidget *widgetWlClipboard;
    QVBoxLayout *verticalLayout_5;
    QCheckBox *cbUseWlClipboard;
    QLabel *lblWlClipboard;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *SettingsDialog)
    {
        if (SettingsDialog->objectName().isEmpty())
            SettingsDialog->setObjectName("SettingsDialog");
        SettingsDialog->resize(549, 755);
        SettingsDialog->setModal(true);
        _13 = new QVBoxLayout(SettingsDialog);
        _13->setSpacing(20);
        _13->setObjectName("_13");
        tabWidget = new QTabWidget(SettingsDialog);
        tabWidget->setObjectName("tabWidget");
        tabRegular = new QWidget();
        tabRegular->setObjectName("tabRegular");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(tabRegular->sizePolicy().hasHeightForWidth());
        tabRegular->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(tabRegular);
        verticalLayout_3->setObjectName("verticalLayout_3");
        groupApp = new QGroupBox(tabRegular);
        groupApp->setObjectName("groupApp");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(groupApp->sizePolicy().hasHeightForWidth());
        groupApp->setSizePolicy(sizePolicy1);
        verticalLayout_2 = new QVBoxLayout(groupApp);
        verticalLayout_2->setObjectName("verticalLayout_2");
        cbAutoUpdate = new QCheckBox(groupApp);
        cbAutoUpdate->setObjectName("cbAutoUpdate");

        verticalLayout_2->addWidget(cbAutoUpdate);

        cbShowVersion = new QCheckBox(groupApp);
        cbShowVersion->setObjectName("cbShowVersion");

        verticalLayout_2->addWidget(cbShowVersion);

        cbAutoHide = new QCheckBox(groupApp);
        cbAutoHide->setObjectName("cbAutoHide");

        verticalLayout_2->addWidget(cbAutoHide);

        cbPreventSleep = new QCheckBox(groupApp);
        cbPreventSleep->setObjectName("cbPreventSleep");

        verticalLayout_2->addWidget(cbPreventSleep);

        cbCloseToTray = new QCheckBox(groupApp);
        cbCloseToTray->setObjectName("cbCloseToTray");

        verticalLayout_2->addWidget(cbCloseToTray);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        lblTrayIconStyle = new QLabel(groupApp);
        lblTrayIconStyle->setObjectName("lblTrayIconStyle");

        horizontalLayout_8->addWidget(lblTrayIconStyle);

        rbIconColorful = new QRadioButton(groupApp);
        rbIconColorful->setObjectName("rbIconColorful");

        horizontalLayout_8->addWidget(rbIconColorful);

        rbIconMono = new QRadioButton(groupApp);
        rbIconMono->setObjectName("rbIconMono");

        horizontalLayout_8->addWidget(rbIconMono);


        verticalLayout_2->addLayout(horizontalLayout_8);


        verticalLayout_3->addWidget(groupApp);

        groupSecurity = new QGroupBox(tabRegular);
        groupSecurity->setObjectName("groupSecurity");
        sizePolicy1.setHeightForWidth(groupSecurity->sizePolicy().hasHeightForWidth());
        groupSecurity->setSizePolicy(sizePolicy1);
        groupSecurity->setCheckable(true);
        groupSecurity->setChecked(false);
        _11 = new QVBoxLayout(groupSecurity);
        _11->setObjectName("_11");
        widgetTlsCert = new QWidget(groupSecurity);
        widgetTlsCert->setObjectName("widgetTlsCert");
        _12 = new QHBoxLayout(widgetTlsCert);
        _12->setObjectName("_12");
        _12->setContentsMargins(0, 0, 0, 0);
        lblTlsCertInfo = new QLabel(widgetTlsCert);
        lblTlsCertInfo->setObjectName("lblTlsCertInfo");
        lblTlsCertInfo->setText(QString::fromUtf8(""));

        _12->addWidget(lblTlsCertInfo);

        lblTlsCert = new QLabel(widgetTlsCert);
        lblTlsCert->setObjectName("lblTlsCert");
        sizePolicy.setHeightForWidth(lblTlsCert->sizePolicy().hasHeightForWidth());
        lblTlsCert->setSizePolicy(sizePolicy);

        _12->addWidget(lblTlsCert);

        lineTlsCertPath = new QLineEdit(widgetTlsCert);
        lineTlsCertPath->setObjectName("lineTlsCertPath");
        lineTlsCertPath->setMinimumSize(QSize(0, 0));

        _12->addWidget(lineTlsCertPath);

        btnTlsCertPath = new QPushButton(widgetTlsCert);
        btnTlsCertPath->setObjectName("btnTlsCertPath");
        btnTlsCertPath->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        QIcon icon(QIcon::fromTheme(QIcon::ThemeIcon::DocumentOpen));
        btnTlsCertPath->setIcon(icon);
        btnTlsCertPath->setFlat(true);

        _12->addWidget(btnTlsCertPath);


        _11->addWidget(widgetTlsCert);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        horizontalLayout_5->setContentsMargins(-1, 0, -1, -1);
        lblTlsKeyLength = new QLabel(groupSecurity);
        lblTlsKeyLength->setObjectName("lblTlsKeyLength");
        sizePolicy.setHeightForWidth(lblTlsKeyLength->sizePolicy().hasHeightForWidth());
        lblTlsKeyLength->setSizePolicy(sizePolicy);

        horizontalLayout_5->addWidget(lblTlsKeyLength);

        comboTlsKeyLength = new QComboBox(groupSecurity);
        comboTlsKeyLength->addItem(QString::fromUtf8("2048"));
        comboTlsKeyLength->addItem(QString::fromUtf8("4096"));
        comboTlsKeyLength->setObjectName("comboTlsKeyLength");

        horizontalLayout_5->addWidget(comboTlsKeyLength);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_2);

        btnTlsRegenCert = new QPushButton(groupSecurity);
        btnTlsRegenCert->setObjectName("btnTlsRegenCert");
        QIcon icon1(QIcon::fromTheme(QIcon::ThemeIcon::ViewRefresh));
        btnTlsRegenCert->setIcon(icon1);

        horizontalLayout_5->addWidget(btnTlsRegenCert);


        _11->addLayout(horizontalLayout_5);

        cbRequireClientCert = new QCheckBox(groupSecurity);
        cbRequireClientCert->setObjectName("cbRequireClientCert");

        _11->addWidget(cbRequireClientCert);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        _11->addItem(verticalSpacer_2);


        verticalLayout_3->addWidget(groupSecurity);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_3->addItem(verticalSpacer_3);

        tabWidget->addTab(tabRegular, QString());
        tabAdvanced = new QWidget();
        tabAdvanced->setObjectName("tabAdvanced");
        sizePolicy.setHeightForWidth(tabAdvanced->sizePolicy().hasHeightForWidth());
        tabAdvanced->setSizePolicy(sizePolicy);
        verticalLayout_4 = new QVBoxLayout(tabAdvanced);
        verticalLayout_4->setObjectName("verticalLayout_4");
        groupNetworking = new QGroupBox(tabAdvanced);
        groupNetworking->setObjectName("groupNetworking");
        sizePolicy1.setHeightForWidth(groupNetworking->sizePolicy().hasHeightForWidth());
        groupNetworking->setSizePolicy(sizePolicy1);
        horizontalLayout = new QHBoxLayout(groupNetworking);
        horizontalLayout->setObjectName("horizontalLayout");
        lblNetworkIp = new QLabel(groupNetworking);
        lblNetworkIp->setObjectName("lblNetworkIp");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(lblNetworkIp->sizePolicy().hasHeightForWidth());
        lblNetworkIp->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(lblNetworkIp);

        comboInterface = new QComboBox(groupNetworking);
        comboInterface->addItem(QString());
        comboInterface->setObjectName("comboInterface");
        sizePolicy2.setHeightForWidth(comboInterface->sizePolicy().hasHeightForWidth());
        comboInterface->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(comboInterface);

        horizontalSpacer = new QSpacerItem(25, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        lblPort = new QLabel(groupNetworking);
        lblPort->setObjectName("lblPort");
        sizePolicy2.setHeightForWidth(lblPort->sizePolicy().hasHeightForWidth());
        lblPort->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(lblPort);

        sbPort = new QSpinBox(groupNetworking);
        sbPort->setObjectName("sbPort");
        sbPort->setEnabled(true);
        sizePolicy2.setHeightForWidth(sbPort->sizePolicy().hasHeightForWidth());
        sbPort->setSizePolicy(sizePolicy2);
        sbPort->setMaximum(65535);
        sbPort->setValue(24800);

        horizontalLayout->addWidget(sbPort);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_3);


        verticalLayout_4->addWidget(groupNetworking);

        groupLogs = new QGroupBox(tabAdvanced);
        groupLogs->setObjectName("groupLogs");
        sizePolicy1.setHeightForWidth(groupLogs->sizePolicy().hasHeightForWidth());
        groupLogs->setSizePolicy(sizePolicy1);
        _3 = new QGridLayout(groupLogs);
        _3->setObjectName("_3");
        _3->setVerticalSpacing(9);
        lblLogLevel = new QLabel(groupLogs);
        lblLogLevel->setObjectName("lblLogLevel");
        sizePolicy.setHeightForWidth(lblLogLevel->sizePolicy().hasHeightForWidth());
        lblLogLevel->setSizePolicy(sizePolicy);

        _3->addWidget(lblLogLevel, 3, 2, 1, 1);

        comboLogLevel = new QComboBox(groupLogs);
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->addItem(QString());
        comboLogLevel->setObjectName("comboLogLevel");

        _3->addWidget(comboLogLevel, 3, 3, 1, 1);

        widgetLogFilename = new QWidget(groupLogs);
        widgetLogFilename->setObjectName("widgetLogFilename");
        sizePolicy1.setHeightForWidth(widgetLogFilename->sizePolicy().hasHeightForWidth());
        widgetLogFilename->setSizePolicy(sizePolicy1);
        _4 = new QHBoxLayout(widgetLogFilename);
        _4->setSpacing(3);
        _4->setObjectName("_4");
        _4->setContentsMargins(0, 0, 0, 0);
        labelLogPath = new QLabel(widgetLogFilename);
        labelLogPath->setObjectName("labelLogPath");
        sizePolicy.setHeightForWidth(labelLogPath->sizePolicy().hasHeightForWidth());
        labelLogPath->setSizePolicy(sizePolicy);

        _4->addWidget(labelLogPath);

        horizontalSpacer_7 = new QSpacerItem(20, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        _4->addItem(horizontalSpacer_7);

        lineLogFilename = new QLineEdit(widgetLogFilename);
        lineLogFilename->setObjectName("lineLogFilename");
        lineLogFilename->setEnabled(true);
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lineLogFilename->sizePolicy().hasHeightForWidth());
        lineLogFilename->setSizePolicy(sizePolicy3);

        _4->addWidget(lineLogFilename);

        btnBrowseLog = new QPushButton(widgetLogFilename);
        btnBrowseLog->setObjectName("btnBrowseLog");
        btnBrowseLog->setEnabled(true);
        btnBrowseLog->setCursor(QCursor(Qt::CursorShape::PointingHandCursor));
        btnBrowseLog->setIcon(icon);
        btnBrowseLog->setFlat(true);

        _4->addWidget(btnBrowseLog);


        _3->addWidget(widgetLogFilename, 8, 0, 1, 4);

        cbLogToFile = new QCheckBox(groupLogs);
        cbLogToFile->setObjectName("cbLogToFile");

        _3->addWidget(cbLogToFile, 3, 0, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        _3->addItem(horizontalSpacer_5, 3, 1, 1, 1);

        lblDebugWarning = new QLabel(groupLogs);
        lblDebugWarning->setObjectName("lblDebugWarning");
        lblDebugWarning->setWordWrap(true);

        _3->addWidget(lblDebugWarning, 9, 0, 1, 4);

        cbGuiDebug = new QCheckBox(groupLogs);
        cbGuiDebug->setObjectName("cbGuiDebug");

        _3->addWidget(cbGuiDebug, 2, 0, 1, 4);


        verticalLayout_4->addWidget(groupLogs);

        groupService = new QGroupBox(tabAdvanced);
        groupService->setObjectName("groupService");
        groupService->setEnabled(true);
        sizePolicy1.setHeightForWidth(groupService->sizePolicy().hasHeightForWidth());
        groupService->setSizePolicy(sizePolicy1);
        groupService->setCheckable(true);
        groupService->setChecked(false);
        _6 = new QGridLayout(groupService);
        _6->setObjectName("_6");
        cbElevateDaemon = new QCheckBox(groupService);
        cbElevateDaemon->setObjectName("cbElevateDaemon");
        cbElevateDaemon->setAutoExclusive(false);

        _6->addWidget(cbElevateDaemon, 1, 0, 1, 1);


        verticalLayout_4->addWidget(groupService);

        widgetLanguage = new QWidget(tabAdvanced);
        widgetLanguage->setObjectName("widgetLanguage");
        horizontalLayout_3 = new QHBoxLayout(widgetLanguage);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        lblLanguage = new QLabel(widgetLanguage);
        lblLanguage->setObjectName("lblLanguage");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(lblLanguage->sizePolicy().hasHeightForWidth());
        lblLanguage->setSizePolicy(sizePolicy4);

        horizontalLayout_3->addWidget(lblLanguage);

        comboLanguage = new QComboBox(widgetLanguage);
        comboLanguage->setObjectName("comboLanguage");

        horizontalLayout_3->addWidget(comboLanguage);


        verticalLayout_4->addWidget(widgetLanguage);

        widgetWlClipboard = new QWidget(tabAdvanced);
        widgetWlClipboard->setObjectName("widgetWlClipboard");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(widgetWlClipboard->sizePolicy().hasHeightForWidth());
        widgetWlClipboard->setSizePolicy(sizePolicy5);
        verticalLayout_5 = new QVBoxLayout(widgetWlClipboard);
        verticalLayout_5->setObjectName("verticalLayout_5");
        cbUseWlClipboard = new QCheckBox(widgetWlClipboard);
        cbUseWlClipboard->setObjectName("cbUseWlClipboard");

        verticalLayout_5->addWidget(cbUseWlClipboard);

        lblWlClipboard = new QLabel(widgetWlClipboard);
        lblWlClipboard->setObjectName("lblWlClipboard");
        lblWlClipboard->setWordWrap(true);

        verticalLayout_5->addWidget(lblWlClipboard);


        verticalLayout_4->addWidget(widgetWlClipboard);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_4->addItem(verticalSpacer);

        tabWidget->addTab(tabAdvanced, QString());

        _13->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(SettingsDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Save);

        _13->addWidget(buttonBox);


        retranslateUi(SettingsDialog);

        QMetaObject::connectSlotsByName(SettingsDialog);
    } // setupUi

    void retranslateUi(QDialog *SettingsDialog)
    {
        SettingsDialog->setWindowTitle(QCoreApplication::translate("SettingsDialog", "Preferences", nullptr));
        groupApp->setTitle(QCoreApplication::translate("SettingsDialog", "App", nullptr));
        cbAutoUpdate->setText(QCoreApplication::translate("SettingsDialog", "Check for updates on startup", nullptr));
        cbShowVersion->setText(QCoreApplication::translate("SettingsDialog", "Include version in the window title", nullptr));
        cbAutoHide->setText(QCoreApplication::translate("SettingsDialog", "Hide the window when the app starts", nullptr));
        cbPreventSleep->setText(QCoreApplication::translate("SettingsDialog", "Prevent this computer from going to sleep", nullptr));
        cbCloseToTray->setText(QCoreApplication::translate("SettingsDialog", "Leave app running in notification area when the window is closed", nullptr));
        lblTrayIconStyle->setText(QCoreApplication::translate("SettingsDialog", "Tray icon style", nullptr));
        rbIconColorful->setText(QCoreApplication::translate("SettingsDialog", "Colorful", nullptr));
        rbIconMono->setText(QCoreApplication::translate("SettingsDialog", "Monocolor", nullptr));
        groupSecurity->setTitle(QCoreApplication::translate("SettingsDialog", "Enable TLS Encryption", nullptr));
        lblTlsCert->setText(QCoreApplication::translate("SettingsDialog", "Certificate", nullptr));
        btnTlsCertPath->setText(QString());
        lblTlsKeyLength->setText(QCoreApplication::translate("SettingsDialog", "Key length", nullptr));

        btnTlsRegenCert->setText(QCoreApplication::translate("SettingsDialog", "Regenerate certificate", nullptr));
        cbRequireClientCert->setText(QCoreApplication::translate("SettingsDialog", "Require client certificates", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabRegular), QCoreApplication::translate("SettingsDialog", "&Regular", nullptr));
        groupNetworking->setTitle(QCoreApplication::translate("SettingsDialog", "Networking", nullptr));
        lblNetworkIp->setText(QCoreApplication::translate("SettingsDialog", "Network IP", nullptr));
        comboInterface->setItemText(0, QCoreApplication::translate("SettingsDialog", "Automatic", nullptr));

        lblPort->setText(QCoreApplication::translate("SettingsDialog", "Port", nullptr));
        groupLogs->setTitle(QCoreApplication::translate("SettingsDialog", "Logs", nullptr));
        lblLogLevel->setText(QCoreApplication::translate("SettingsDialog", "Level", nullptr));
        comboLogLevel->setItemText(0, QCoreApplication::translate("SettingsDialog", "Fatal", nullptr));
        comboLogLevel->setItemText(1, QCoreApplication::translate("SettingsDialog", "Error", nullptr));
        comboLogLevel->setItemText(2, QCoreApplication::translate("SettingsDialog", "Warning", nullptr));
        comboLogLevel->setItemText(3, QCoreApplication::translate("SettingsDialog", "Note", nullptr));
        comboLogLevel->setItemText(4, QCoreApplication::translate("SettingsDialog", "Info", nullptr));
        comboLogLevel->setItemText(5, QCoreApplication::translate("SettingsDialog", "Debug", nullptr));
        comboLogLevel->setItemText(6, QCoreApplication::translate("SettingsDialog", "Debug1", nullptr));
        comboLogLevel->setItemText(7, QCoreApplication::translate("SettingsDialog", "Debug2", nullptr));

        labelLogPath->setText(QCoreApplication::translate("SettingsDialog", "Log path", nullptr));
        btnBrowseLog->setText(QString());
        cbLogToFile->setText(QCoreApplication::translate("SettingsDialog", "Log to file", nullptr));
        lblDebugWarning->setText(QCoreApplication::translate("SettingsDialog", "Using a Debug log level may affect performance. Only use a Debug level if you are attempting to debug an issue or are gathering logs to submit with a bug report.", nullptr));
        cbGuiDebug->setText(QCoreApplication::translate("SettingsDialog", "Enable GUI debug messages", nullptr));
        groupService->setTitle(QCoreApplication::translate("SettingsDialog", "Use background service (daemon)", nullptr));
        cbElevateDaemon->setText(QCoreApplication::translate("SettingsDialog", "Always run as system (work at login screen and UAC)", nullptr));
#if QT_CONFIG(tooltip)
        widgetLanguage->setToolTip(QCoreApplication::translate("SettingsDialog", "Force a language to be used for the GUI.", nullptr));
#endif // QT_CONFIG(tooltip)
        lblLanguage->setText(QCoreApplication::translate("SettingsDialog", "Language", nullptr));
        cbUseWlClipboard->setText(QCoreApplication::translate("SettingsDialog", "Enable wl-clipboard support", nullptr));
        lblWlClipboard->setText(QCoreApplication::translate("SettingsDialog", "<html><head/><body><p>Requires the wl-clipboard package</p><p>When using wl-clipboard v2.2.1, there is a focus stealing bug that may make Deskflow harder to use. This has been fixed when using the wl-clipboard master branch, unless your Compositor lacks wlroots-data-control protocol support.</p></body></html>", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabAdvanced), QCoreApplication::translate("SettingsDialog", "&Advanced", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SettingsDialog: public Ui_SettingsDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SETTINGSDIALOG_H
