/****************************************************************************
** Meta object code from reading C++ file 'CoreProcess.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../src/lib/gui/core/CoreProcess.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'CoreProcess.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t {};
} // unnamed namespace

template <> constexpr inline auto deskflow::gui::CoreProcess::qt_create_metaobjectdata<qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "deskflow::gui::CoreProcess",
        "error",
        "",
        "deskflow::gui::CoreProcess::Error",
        "logLine",
        "line",
        "connectionStateChanged",
        "deskflow::gui::CoreProcess::ConnectionState",
        "state",
        "processStateChanged",
        "deskflow::gui::CoreProcess::ProcessState",
        "secureSocket",
        "enabled",
        "daemonIpcClientConnectionFailed",
        "onProcessFinished",
        "exitCode",
        "QProcess::ExitStatus",
        "onProcessReadyReadStandardOutput",
        "onProcessReadyReadStandardError",
        "daemonIpcClientConnected",
        "ProcessState",
        "Starting",
        "Started",
        "Stopping",
        "Stopped",
        "RetryPending"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'error'
        QtMocHelpers::SignalData<void(deskflow::gui::CoreProcess::Error)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 1 },
        }}),
        // Signal 'logLine'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'connectionStateChanged'
        QtMocHelpers::SignalData<void(deskflow::gui::CoreProcess::ConnectionState)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'processStateChanged'
        QtMocHelpers::SignalData<void(deskflow::gui::CoreProcess::ProcessState)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 8 },
        }}),
        // Signal 'secureSocket'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'daemonIpcClientConnectionFailed'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onProcessFinished'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { 0x80000000 | 16, 2 },
        }}),
        // Slot 'onProcessReadyReadStandardOutput'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onProcessReadyReadStandardError'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'daemonIpcClientConnected'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ProcessState'
        QtMocHelpers::EnumData<enum ProcessState>(20, 20, QMC::EnumIsScoped).add({
            {   21, ProcessState::Starting },
            {   22, ProcessState::Started },
            {   23, ProcessState::Stopping },
            {   24, ProcessState::Stopped },
            {   25, ProcessState::RetryPending },
        }),
    };
    return QtMocHelpers::metaObjectData<CoreProcess, qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject deskflow::gui::CoreProcess::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t>.metaTypes,
    nullptr
} };

void deskflow::gui::CoreProcess::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CoreProcess *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->error((*reinterpret_cast<std::add_pointer_t<deskflow::gui::CoreProcess::Error>>(_a[1]))); break;
        case 1: _t->logLine((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->connectionStateChanged((*reinterpret_cast<std::add_pointer_t<deskflow::gui::CoreProcess::ConnectionState>>(_a[1]))); break;
        case 3: _t->processStateChanged((*reinterpret_cast<std::add_pointer_t<deskflow::gui::CoreProcess::ProcessState>>(_a[1]))); break;
        case 4: _t->secureSocket((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->daemonIpcClientConnectionFailed(); break;
        case 6: _t->onProcessFinished((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 7: _t->onProcessReadyReadStandardOutput(); break;
        case 8: _t->onProcessReadyReadStandardError(); break;
        case 9: _t->daemonIpcClientConnected(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CoreProcess::*)(deskflow::gui::CoreProcess::Error )>(_a, &CoreProcess::error, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CoreProcess::*)(const QString & )>(_a, &CoreProcess::logLine, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CoreProcess::*)(deskflow::gui::CoreProcess::ConnectionState )>(_a, &CoreProcess::connectionStateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CoreProcess::*)(deskflow::gui::CoreProcess::ProcessState )>(_a, &CoreProcess::processStateChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CoreProcess::*)(bool )>(_a, &CoreProcess::secureSocket, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CoreProcess::*)()>(_a, &CoreProcess::daemonIpcClientConnectionFailed, 5))
            return;
    }
}

const QMetaObject *deskflow::gui::CoreProcess::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *deskflow::gui::CoreProcess::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8deskflow3gui11CoreProcessE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int deskflow::gui::CoreProcess::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void deskflow::gui::CoreProcess::error(deskflow::gui::CoreProcess::Error _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void deskflow::gui::CoreProcess::logLine(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void deskflow::gui::CoreProcess::connectionStateChanged(deskflow::gui::CoreProcess::ConnectionState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void deskflow::gui::CoreProcess::processStateChanged(deskflow::gui::CoreProcess::ProcessState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void deskflow::gui::CoreProcess::secureSocket(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void deskflow::gui::CoreProcess::daemonIpcClientConnectionFailed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
