/*
 * Deskflow -- mouse and keyboard sharing utility
 * SPDX-FileCopyrightText: (C) 2024 - 2025 Chris Rizzitello <sithlord48@gmail.com>
 * SPDX-FileCopyrightText: (C) 2025 Symless Ltd.
 * SPDX-License-Identifier: GPL-2.0-only WITH LicenseRef-OpenSSL-Exception
 */

#pragma once

const auto kVersion = "1.26.0.0";
const auto kVersionGitSha = "760e3b99";
const auto kDisplayVersion = 0
                           ? "1.26.0.0 (760e3b99)"
                           : "1.26.0";
